@@ -1,11 +1,13 @@
 from pathlib import Path
 import shutil
+from frontier.utils import prepare_scaffold
 
 
 class Tailwind():
     def install(self, resource_path, base_dir):
         self.base_dir = base_dir
         self.resource_path = resource_path
+        prepare_scaffold(self.base_dir, self.resource_path)
         self.components_dir = Path.joinpath(self.resource_path, "css/")
 
         self.tailwind_source = Path.joinpath(
