@@ -1,6 +1,7 @@
 import React from "react";
 import ReactDOM from "react-dom";
-import "./app.css";
+import "tailwindcss/tailwind.css";
+import "./index.css";
 import App from "./App";
 
 ReactDOM.render(<App />, document.getElementById("app"));
