@@ -1,6 +1,6 @@
 import Vue from "vue";
 import App from "./App.vue";
-import "./app.css";
+import "tailwindcss/tailwind.css";
 
 new Vue({
 	el: "#app",
